/********************************************************************************
 *
 *	fl_17703.h
 *
 * 	This is flash memory driver header file.
 *
 *	history : 2010/04/13    start
 *			  2011/03/22	Change software wait
 *
 *	Copyright (C) SEIKO EPSON CORPORATION 2010-2014. All rights reserved.
********************************************************************************/
// Address definition
#define		FLASH_COM1_ADDR		(0x555 << 1)	// Address for flash command1
#define		FLASH_COM2_ADDR		(0x2aa << 1)	// Address for flash command2

#define     DSIO_STS			0xffffc0
#define     DSIO_DAT			0xffffc2

// Register definition
//OSC
#define OSC_SRC				*(volatile unsigned char *)(0x5060)
//SVD
#define OSC_SVD				*(volatile unsigned char *)(0x5066)
#define SVD_EN					*(volatile unsigned char *)(0x5100)
#define SVD_CMP				*(volatile unsigned char *)(0x5101)
#define SVD_RSLT 				*(volatile unsigned char *)(0x5102)
#define SVD_IMSK				*(volatile unsigned char *)(0x5103)
//Debug mode control
#define MISC_DMODE2			*(volatile unsigned short *)(0x5322)
// VD1 control
//VD1
#define VD1_CTL				*(volatile unsigned short *)(0x5120)
#define VD1_SEL				*(volatile unsigned char *)(0x5122)
#define MISC_PROT 				*(volatile unsigned short *)(0x5324)
#define VD1_CTL_VD1MD			0x01			// Flash erase/program mode

// Command definition
#define		FLASH_ERASE1		0xaa			// Flash erase command1
#define		FLASH_ERASE2		0x55			// Flash erase command2
#define		FLASH_ERASE3		0x80			// Flash erase command3
#define		FLASH_ERASE4		0xaa			// Flash erase command4
#define		FLASH_ERASE5		0x55			// Flash erase command5
#define		FLASH_ERASE6		0x10			// Flash erase command6 chip all erase
#define		FLASH_ERASE6_S		0x30			// Flash erase command6 sector erase

#define		FLASH_PROG1			0xaa			// Flash byte program command1
#define		FLASH_PROG2			0x55			// Flash byte program command2
#define		FLASH_PROG3			0xa0			// Flash byte program command3

#define		CHIP_ERASE			1
#define 		SECT_ERASE			2

// Error code define
#define		FLS_E_SUCCESS		0				// Successful
#define		FLS_E_VERIFY		1				// Verify Error
#define		FLS_E_PARAM1		3				// Start Block Error
#define		FLS_E_PARAM2		4				// End Block Error
#define		FLS_E_CHANGE		5				// Change Control Register
#define		FLS_E_REGERR		6				// Control Register Error

#define		FLS_B_DQ6			0x0040			// Toggle Bit

// Define information define
#define		FLS_SCTSIZE			4096			// Bytes/Sector
#define		FLS_SCTMAX			65	 			// Number of Sectors
#define		FLS_INIDAT			0xFFFF			// Initial Data
#define		FLS_FILL_L			0x00FF			// Fill H byte of Write data
#define		FLS_FILL_H			0xFF00			// Fill L byte of Write data
#define		FLS_MAXSIZE			1024
#define		FLS_TOPADDR			0x8000			// Top address of Flash Memory

#define 		SOFT_WAIT			2500			// Software wait
													// IOSC2.7MHz(Max3.24MHz)/8ms

